
# This file was generated by 'versioneer.py' (0.18) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2018-07-19T14:54:26-0700",
 "dirty": false,
 "error": null,
 "full-revisionid": "a28ba8ca98aee258a6bd9d517c927e0f89ce78a9",
 "version": "0.1.0-alpha.2"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)



import os

def file_writer(folder, filename, content):
    with open(os.path.join(folder, filename), 'w') as f:
        f.write(content)

def folder_creator(base_dir, folder_name):
    new_folder = os.path.join(base_dir, folder_name)
    if not os.path.exists(new_folder):
        os.mkdir(new_folder)
    
    return new_folder




import argparse

from . import init

def parse_args():
    parser = argparse.ArgumentParser(description='Package Creator')
    subparsers = parser.add_subparsers(dest='cmd')
    init_parser = subparsers.add_parser('init')

    return parser.parse_args()

def main():
    args = parse_args()
    if args.cmd == 'init':
        init()

if __name__ == '__main__':
    main()